//
// COPYRIGHT LICENSE: This information contains sample code provided in source code form. You may copy, 
// modify, and distribute these sample programs in any form without payment to IBM for the purposes of 
// developing, using, marketing or distributing application programs conforming to the application 
// programming interface for the operating platform for which the sample code is written. 
// Notwithstanding anything to the contrary, IBM PROVIDES THE SAMPLE SOURCE CODE ON AN "AS IS" BASIS 
// AND IBM DISCLAIMS ALL WARRANTIES, EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, ANY IMPLIED 
// WARRANTIES OR CONDITIONS OF MERCHANTABILITY, SATISFACTORY QUALITY, FITNESS FOR A PARTICULAR PURPOSE, 
// TITLE, AND ANY WARRANTY OR CONDITION OF NON-INFRINGEMENT. IBM SHALL NOT BE LIABLE FOR ANY DIRECT, 
// INDIRECT, INCIDENTAL, SPECIAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR OPERATION OF THE 
// SAMPLE SOURCE CODE. IBM HAS NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS 
// OR MODIFICATIONS TO THE SAMPLE SOURCE CODE.  
//
// (C) COPYRIGHT International Business Machines Corp., 2003,2011
// All Rights Reserved * Licensed Materials - Property of IBM
//
package com.ibm.websphere.samples.pbw.jpa;

import javax.persistence.Column;
import javax.persistence.Embeddable;
import javax.persistence.EmbeddedId;
import javax.persistence.Entity;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.MapsId;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;

/**
 * Bean mapping for the ORDERITEM table.
 */
@Entity(name="OrderItem")
@Table(name="ORDERITEM", schema="APP")
@NamedQueries({
	@NamedQuery(
		name="removeAllOrderItem",
		query="delete from OrderItem")
})
public class OrderItem {
	/**
	 * Composite Key class for Entity Bean: OrderItem
	 * 
	 * Key consists of essentially two foreign key relations, but is mapped
	 * as foreign keys.
	 */
	@Embeddable
	public static class PK implements java.io.Serializable {
		static final long serialVersionUID = 3206093459760846163L;
		public String inventoryID;
		public String order_orderID;

		public PK() {}

		public PK(String inventoryID, String argOrder) {
			this.inventoryID = inventoryID;
			this.order_orderID = argOrder;
		}
		/**
		 * Returns true if both keys are equal.
		 */
		public boolean equals(Object otherKey) {
			if (otherKey instanceof PK) {
				PK o = (PK) otherKey;
				return ((this.inventoryID.equals(o.inventoryID))
						&& (this.order_orderID.equals(o.order_orderID)));
			}
			return false;
		}
		/**
		 * Returns the hash code for the key.
		 */
		public int hashCode() {
			return (inventoryID.hashCode() + order_orderID.hashCode());
		}
	}

	@SuppressWarnings("unused")
	@EmbeddedId
	private OrderItem.PK id;
	private String name;
	private String pkginfo;
	private float price;
	private float cost;
	private int category;
	private int quantity;
	private String sellDate;

	@ManyToOne
	@MapsId("inventoryID")
	@JoinColumn(name="inventoryID")
	private Inventory inventory;
	@ManyToOne
	@MapsId("order_orderID")
	@JoinColumn(name="ORDER_ORDERID")
	private Order order;

	public int getCategory() {
		return category;
	}
	public void setCategory(int category) {
		this.category = category;
	}
	public float getCost() {
		return cost;
	}
	public void setCost(float cost) {
		this.cost = cost;
	}
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public String getPkginfo() {
		return pkginfo;
	}
	public void setPkginfo(String pkginfo) {
		this.pkginfo = pkginfo;
	}
	public float getPrice() {
		return price;
	}
	public void setPrice(float price) {
		this.price = price;
	}
	public int getQuantity() {
		return quantity;
	}
	public void setQuantity(int quantity) {
		this.quantity = quantity;
	}
	public String getSellDate() {
		return sellDate;
	}
	public void setSellDate(String sellDate) {
		this.sellDate = sellDate;
	}

	public OrderItem() {} 
	public OrderItem(Inventory inv) {
		setInventory(inv);
		setName(inv.getName());
		setPkginfo(inv.getPkginfo());
		setPrice(inv.getPrice());
		setCost(inv.getCost());
		setCategory(inv.getCategory());
	}

	public OrderItem(Order order, String orderID, 
			Inventory inv, String name, String pkginfo, float price, float cost,
			int quantity, int category, String sellDate) {
		setInventory(inv);
		setName(name);
		setPkginfo(pkginfo);
		setPrice(price);
		setCost(cost);
		setQuantity(quantity);
		setCategory(category);
		setSellDate(sellDate);
		setOrder(order);
		id=new OrderItem.PK(inv.getInventoryId(),order.getOrderID());
	}
	public Inventory getInventory() {
		return inventory;
	}
	public void setInventory(Inventory inv) {
		this.inventory = inv;
	}
	public Order getOrder() {
		return order;
	}
	/**
	 * Sets the order for this item
	 * Also updates the sellDate
	 * @param order
	 */
	public void setOrder(Order order) {
		this.order = order;
		this.sellDate=order.getSellDate();
	}
} 